Index: trunk/ippToPsps/scripts/pspsSchema2xml.pl
===================================================================
--- trunk/ippToPsps/scripts/pspsSchema2xml.pl	(revision 27362)
+++ trunk/ippToPsps/scripts/pspsSchema2xml.pl	(revision 27363)
@@ -29,5 +29,5 @@
 defined $type;
 
-if ($type ne "DT" && $type ne "IN" && $type ne "OB") {
+if ($type ne "DT" && $type ne "IN" && $type ne "OB" && $type ne "ST") {
 
     print "Don't understand type '$type'\n"; 
@@ -45,4 +45,5 @@
 elsif ($type eq "DT") {createDetections($schemaPath);}
 elsif ($type eq "OB") {createDiffs($schemaPath);}
+elsif ($type eq "ST") {createStacks($schemaPath);}
 
 # finish up XML
@@ -54,5 +55,5 @@
 
 
 # creates detections mappings
 sub createInit {
     my ($schemaPath) = @_;
@@ -70,5 +71,5 @@
 }
 
 # creates init batch mappings
 sub createDetections {
     my ($schemaPath) = @_;
@@ -81,5 +82,5 @@
 }
 
 # creates diff batch mappings
 sub createDiffs {
     my ($schemaPath) = @_;
@@ -89,4 +90,15 @@
     parseTable("$schemaPath/PanSTARRS.Tables.Slice.sql", "dbo.StackLowSigDelta");
     parseTable("$schemaPath/PanSTARRS.Tables.Slice.sql", "dbo.StackHighSigDelta");
+}
+
+# creates stack batch tables
+sub createStacks {
+    my ($schemaPath) = @_;
+
+    parseTable("$schemaPath/PanSTARRS.Tables.Slice.sql", "dbo.StackMeta");
+    parseTable("$schemaPath/PanSTARRS.Tables.Slice.sql", "dbo.StackDetection");
+    parseTable("$schemaPath/PanSTARRS.Tables.LoadMerge.sql", "dbo.SkinnyObject");
+    parseTable("$schemaPath/PanSTARRS.Tables.Slice.sql", "dbo.StackOrphan");
+    parseTable("$schemaPath/PanSTARRS.Tables.Common.sql", "dbo.ObjectCalColor");
 }
 
@@ -54,5 +55,5 @@
 
 
-# creates detections mappings
+# creates detections tables
 sub createInit {
     my ($schemaPath) = @_;
@@ -70,5 +71,5 @@
 }
 
-# creates init batch mappings
+# creates init batch tables
 sub createDetections {
     my ($schemaPath) = @_;
@@ -81,5 +82,5 @@
 }
 
-# creates diff batch mappings
+# creates diff batch tables
 sub createDiffs {
     my ($schemaPath) = @_;
